package com.cmcc.system;

import android.content.Context;
import android.os.Build;
import android.provider.Settings;
import com.cmcc.system.internal.IniReader;

import java.net.Inet4Address;
import java.net.InetAddress;
import java.net.NetworkInterface;
import java.net.SocketException;
import java.util.Enumeration;

public class Param {
	private static final String SPLIT_STR = "|";

    /**
     * 获取设备mac地址，优先获取RJ接口MAC，获取不到则获取WIFI接口MAC
     * @return mac地址
     */
    public static final String getMacAddress() {
        return getDefaultString(getEthMacAddress()) + SPLIT_STR + getDefaultString(getWlanMacAddress());
    }

    /**
     * 获取获取WIFI接口的MAC
     * @return mac地址
     */
    public static final String getWlanMacAddress() {
        return getMacAddress("wlan");
    }

    /**
     * 获取获取RJ接口的MAC
     * @return mac地址
     */
    public static final String getEthMacAddress() {
        return getMacAddress("eth");
    }

    /**
     * 获取指定网口的mac地址
     * @param name 网口名称：eth, wlan, ...
     * @return mac地址
     */
    private static final String getMacAddress(String name) {
        try {
            Enumeration<NetworkInterface> en = NetworkInterface.getNetworkInterfaces();
            while (en.hasMoreElements()) {
                NetworkInterface networkInterface = en.nextElement();
                byte[] mac = networkInterface.getHardwareAddress();
                if (!networkInterface.getName().startsWith(name) || mac == null) {
                    continue;
                }
                return formatMac(mac);
            }
        } catch (SocketException ex) { }
        return null;
    }

    /**
     * 格式化mac地址为可读文本，格式：010203040506
     * @param mac mac地址保存数组
     * @return mac地址的可读文本
     */
    private static final String formatMac(byte[] mac) {
        StringBuffer sb = new StringBuffer();
        for(int i=0;i<mac.length;i++){
            String s = Integer.toHexString(mac[i] & 0xFF);
            sb.append(s.length()==1?0+s:s);
        }
        return sb.toString().toUpperCase();
    }

    /**
     * 获取设备ipv4地址，优先获取RJ接口ip，获取不到则获取WIFI接口ip
     * @return ipv4地址
     */
    public static final String getIpv4Address() {
        return getDefaultString(getEthIpv4Address()) + SPLIT_STR + getDefaultString(getWlanIpv4Address());
    }
    /**
     * 获取获取WIFI接口的IP
     * @return mac地址
     */
    public static final String getWlanIpv4Address() {
        return getIpv4Address("wlan");
    }
    /**
     * 获取获取RJ接口的IP
     * @return ip地址
     */
    public static final String getEthIpv4Address() {
        return getIpv4Address("eth");
    }
    /**
     * 获取指定网口的ipv4地址
     * @param name 网口名称：eth, wlan, ...
     * @return ip地址
     */
    private static final String getIpv4Address(String name) {
        try {
            Enumeration<NetworkInterface> en = NetworkInterface.getNetworkInterfaces();
            while (en.hasMoreElements()) {
                NetworkInterface networkInterface = en.nextElement();
                if (!networkInterface.getName().startsWith(name)) {
                    continue;
                }
                Enumeration<InetAddress> enumIpAddr = networkInterface.getInetAddresses();
                while (enumIpAddr.hasMoreElements()) {
                    InetAddress inetAddress = enumIpAddr.nextElement();
                    if (inetAddress instanceof Inet4Address
                            && !inetAddress.isLoopbackAddress()) {
                        return inetAddress.getHostAddress();
                    }
                }
            }
        } catch (SocketException ex) { }
        return null;
    }

    /**
     * 获取终端串号（易视腾机顶盒专用）
     * @return 终端串号
     */
    public static final String getDeviceSerialNumber() {
        return new IniReader("/etc/ini/DeviceID.ini").getValue("DEVICE", "DeviceId");
    }

    /**
     * 获取终端唯一ID
     * @param ctx Context对象
     * @return 终端唯一ID
     */
    public static final String getDeviceUniqueId(Context ctx) {
        return Settings.Secure.getString(ctx.getContentResolver(), Settings.Secure.ANDROID_ID);
    }

    /**
     * 获取设备型号
     * @return 设备型号
     */
    public static final String getDeviceModel() {
        return Build.MODEL;
    }
    
    private static final String getDefaultString(String str) {
    	return str == null ? "" : str;
    }
}
